Check the names of dashboards in tableau, according to the style guide. The wrong dashboards will be returned together with the reason why it is a wrong name
check_dashboard_names(import_files)the wrongly named dashboards
selected tableau file or folder, to check the names of the dashboards. If it is only one file, make sure it is a twb file.
Other xml:
adjust_tableau_size(),
get_actions(),
get_folders(),
get_hierarchy(),
get_nodenames(),
get_parameter(),
get_revision(),
get_server_location(),
get_tableau_data_source(),
get_variable_folders(),
get_variables(),
get_workbook_id(),
get_workbook_tabs(),
make_rootnodes()